<?php

declare(strict_types = 1);

namespace Drupal\data_pipelines;

use Symfony\Component\Validator\ConstraintViolationListInterface;

/**
 * Interface DatasetInterface.
 *
 * @package Drupal\data_pipelines
 */
interface DatasetPipelineInterface {

  /**
   * A method to validate the data from the dataset source.
   *
   * @param \Drupal\data_pipelines\DatasetData $data
   *   The dataset data.
   *
   * @return \Symfony\Component\Validator\ConstraintViolationListInterface
   *   Violations.
   */
  public function validate(DatasetData $data): ConstraintViolationListInterface;

  /**
   * A method to transform the dataset data.
   *
   * @param \Drupal\data_pipelines\DatasetData $data
   *   The dataset data.
   */
  public function transform(DatasetData $data): DatasetData;

}
