<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\EntityHandlers;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\Sql\SqlContentEntityStorage;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\data_pipelines\Index\IndexingRequest;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a storage handler for Dataset entities.
 */
class DatasetStorage extends SqlContentEntityStorage {

  /**
   * Queue factory.
   *
   * @var \Drupal\Core\Queue\QueueFactory
   */
  protected $queue;

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    $instance = parent::createInstance($container, $entity_type);
    $instance->queue = $container->get('queue');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function delete(array $entities) {
    parent::delete($entities);
    foreach ($entities as $entity) {
      $queue = $this->queue->get('data_pipelines_index:' . $entity->id());
      // Clear any previous operations.
      $queue->deleteQueue();
      assert($entity instanceof DatasetInterface);
      $queue->createItem(IndexingRequest::deleteDataSet($entity));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function save(EntityInterface $entity) {
    $result = parent::save($entity);
    assert($entity instanceof DatasetInterface);
    if ($entity->isSyncing()) {
      return $result;
    }
    $queue = $this->queue->get('data_pipelines_index:' . $entity->id());
    // Clear any previous operations.
    $queue->deleteQueue();
    $queue->createItem(IndexingRequest::forDataSet($entity));
    return $result;
  }

}
