<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Index;

use Drupal\data_pipelines\Entity\DatasetInterface;

/**
 * Defines an interface for indexing datasets.
 */
interface DatasetIndexerInterface {

  /**
   * Indexes a data set.
   *
   * @param \Drupal\data_pipelines\Entity\DatasetInterface $dataset
   *   Dataset to index.
   *
   * @return bool
   *   TRUE if indexing succeeded.
   */
  public function indexDataSet(DatasetInterface $dataset): bool;

  /**
   * Deletes a dataset from the index.
   *
   * @param \Drupal\data_pipelines\Index\IndexingRequest $request
   *   Deletion request.
   *
   * @throws \Drupal\data_pipelines\Index\DatasetNotRemovedFromIndexException
   *   On error.
   */
  public function deleteDataSetFromIndex(IndexingRequest $request): void;

}
