<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Index;

use Drupal\data_pipelines\Entity\DatasetInterface;

/**
 * Defines a value object for an indexing request.
 */
final class IndexingRequest {

  const TYPE_INDEX = 'index';
  const TYPE_DELETE = 'delete';

  /**
   * UUID to delete.
   *
   * @var string
   */
  protected $uuid;

  /**
   * Label to delete.
   *
   * @var string
   */
  protected $label;

  /**
   * Indexing type.
   *
   * @var string
   */
  protected $type;

  /**
   * Constructs a new IndexDeletionRequest.
   *
   * @param string $uuid
   *   UUID.
   * @param string $label
   *   Label.
   * @param string $type
   *   Indexing type.
   */
  protected function __construct(string $uuid, string $label, string $type) {
    $this->uuid = $uuid;
    $this->label = $label;
    $this->type = $type;
  }

  /**
   * Factory method.
   *
   * @param \Drupal\data_pipelines\Entity\DatasetInterface $dataset
   *   Dataset.
   *
   * @return \Drupal\data_pipelines\Index\IndexingRequest
   *   Deletion request.
   */
  public static function deleteDataSet(DatasetInterface $dataset): IndexingRequest {
    return new static($dataset->uuid(), $dataset->label(), self::TYPE_DELETE);
  }

  /**
   * Factory method.
   *
   * @param \Drupal\data_pipelines\Entity\DatasetInterface $dataset
   *   Dataset.
   *
   * @return \Drupal\data_pipelines\Index\IndexingRequest
   *   Deletion request.
   */
  public static function forDataSet(DatasetInterface $dataset): IndexingRequest {
    return new static($dataset->uuid(), $dataset->label(), self::TYPE_INDEX);
  }

  /**
   * Gets value of Uuid.
   *
   * @return string
   *   Value of Uuid.
   */
  public function getUuid(): string {
    return $this->uuid;
  }

  /**
   * Gets value of Label.
   *
   * @return string
   *   Value of Label.
   */
  public function getLabel(): string {
    return $this->label;
  }

  /**
   * Checks if is delete request.
   *
   * @return bool
   *   TRUE if is delete request.
   */
  public function isDeleteRequest(): bool {
    return $this->type === self::TYPE_DELETE;
  }

}
