<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Plugin\DatasetSource;

use Drupal\data_pipelines\DatasetData;
use Drupal\data_pipelines\Entity\DatasetInterface;

/**
 * Defines a trait for CSV source plugins.
 */
trait CsvSourceTrait {

  /**
   * {@inheritdoc}
   */
  public function extractDataFromDataSet(DatasetInterface $dataset): \Generator {
    $resource = $this->getResource($dataset);
    if (is_resource($resource)) {
      $header = fgetcsv($resource);
      $header_length = count($header);
      while (($file_row = fgetcsv($resource)) !== FALSE) {
        // Make sure the row has exactly the same number of columns as the
        // header.
        $normalized_row = array_pad(array_slice($file_row, 0, $header_length), $header_length, NULL);
        yield new DatasetData(array_combine($header, $normalized_row));
      }
      fclose($resource);
    }
  }

}
