<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Plugin\DatasetSource;

use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\data_pipelines\Source\DatasetSourceBase;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\file\FileInterface;

/**
 * Defines a base class for dataset sources that use files.
 */
abstract class FileBase extends DatasetSourceBase {

  /**
   * Gets allowed file extensions.
   *
   * @return string
   *   Allowed file extensions, space separated.
   */
  abstract protected function getFileExtensions(): string;

  /**
   * {@inheritdoc}
   */
  protected function getResource(DatasetInterface $dataset) {
    $file_entity = $dataset->get($this->getFieldName())->entity;
    if (!$file_entity) {
      return NULL;
    }
    assert($file_entity instanceof FileInterface);
    return fopen($file_entity->getFileUri(), 'r');
  }

  /**
   * {@inheritdoc}
   */
  public function buildFieldDefinitions(): array {
    return [
      $this->getFieldName() => BaseFieldDefinition::create('file')
        ->setLabel(new TranslatableMarkup('File'))
        ->setDescription(new TranslatableMarkup('The file for the dataset.'))
        ->setRequired(TRUE)
        ->setSetting('file_extensions', $this->getFileExtensions())
        ->setDisplayOptions('form', [
          'type' => 'file_generic',
        ]
      ),
    ];
  }

}
