<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Plugin\DatasetSource;

use Drupal\data_pipelines\DatasetData;
use Drupal\data_pipelines\Entity\DatasetInterface;

/**
 * Defines a trait for JSON source plugins.
 */
trait JsonSourceTrait {

  /**
   * {@inheritdoc}
   */
  public function extractDataFromDataSet(DatasetInterface $dataset): \Generator {
    $resource = $this->getResource($dataset);
    if (is_resource($resource)) {
      $json = json_decode(stream_get_contents($resource), TRUE);
      if (array_values($json) === $json) {
        // Values are an array - e.g. [{record...}, {record...}].
        foreach ($json as $record) {
          yield new DatasetData($record);
        }
        return;
      }
      yield new DatasetData($json);
      fclose($resource);
    }
  }

}
