<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Plugin\DatasetSource;

use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\data_pipelines\Source\DatasetSourceBase;
use Drupal\data_pipelines\Entity\DatasetInterface;

/**
 * Defines a base class for dataset sources that use a string.
 */
abstract class StringBase extends DatasetSourceBase {

  /**
   * {@inheritdoc}
   */
  public function buildFieldDefinitions(): array {
    return [
      $this->getFieldName() => BaseFieldDefinition::create('string_long')
        ->setLabel(new TranslatableMarkup('Data'))
        ->setDescription(new TranslatableMarkup('The data for the dataset'))
        ->setDisplayOptions('form', [
          'type' => 'string_textarea',
          'weight' => 25,
          'settings' => [
            'rows' => 4,
          ],
        ]),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getResource(DatasetInterface $dataset) {
    if ($resource = fopen('php://temp', 'r+')) {
      fwrite($resource, $dataset->get($this->getFieldName())->value);
      rewind($resource);
      return $resource;
    }
    return NULL;
  }

}
