<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Plugin\QueueWorker;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\data_pipelines\Index\IndexingRequest;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a queue worker for indexing an item.
 *
 * @QueueWorker(
 *   id = "data_pipelines_index",
 *   title = @Translation("Indexing queue worker"),
 *   deriver = \Drupal\data_pipelines\Plugin\Derivative\DatasetQueueWorkerDeriver::class,
 * )
 */
final class Indexer extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * Dataset indexer.
   *
   * @var \Drupal\data_pipelines\Index\DatasetIndexerInterface
   */
  protected $indexer;

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = new static($configuration, $plugin_id, $plugin_definition);
    $instance->indexer = $container->get('data_pipelines.indexer');
    $instance->entityTypeManager = $container->get('entity_type.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    if (!($data instanceof IndexingRequest)) {
      return;
    }
    if (!$data->isDeleteRequest()) {
      $dataset = $this->entityTypeManager->getStorage('data_pipelines')->load($this->pluginDefinition['data_pipelines_id']);
      if ($dataset) {
        assert($dataset instanceof DatasetInterface);
        $this->indexer->indexDataSet($dataset);
      }
      return;
    }
    // We let the exception bubble here, so the item remains in the queue.
    $this->indexer->deleteDataSetFromIndex($data);
  }

}
