<?php

declare(strict_types = 1);

namespace Drupal\data_pipelines\Source;

use Drupal\Core\Plugin\PluginBase;
use Drupal\data_pipelines\Entity\DatasetInterface;

/**
 * Defines a base plugin for data set source plugins.
 */
abstract class DatasetSourceBase extends PluginBase implements DatasetSourceInterface {

  /**
   * Gets the field name for this source.
   *
   * @return string
   *   Field name.
   */
  abstract protected function getFieldName(): string;

  /**
   * Gets a resource for the data source.
   *
   * @param \Drupal\data_pipelines\Entity\DatasetInterface $dataset
   *   The dataset entity to get a resource for.
   *
   * @return resource|null
   *   Resource for this dataset source.
   */
  abstract protected function getResource(DatasetInterface $dataset);

}
