<?php

declare(strict_types=1);

namespace Drupal\data_pipelines_test;

use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\data_pipelines\Index\DatasetIndexerInterface;
use Drupal\data_pipelines\Index\IndexingRequest;

/**
 * Defines a memory based indexer for datasets.
 */
class MemoryDatasetIndexer implements DatasetIndexerInterface {

  /**
   * Indexed data.
   *
   * @var array
   */
  protected $data = [];

  /**
   * {@inheritdoc}
   */
  public function indexDataSet(DatasetInterface $dataset): bool {
    $this->data[$dataset->uuid()] = iterator_to_array($dataset->data());
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function deleteDataSetFromIndex(IndexingRequest $request): void {
    unset($this->data[$request->getUuid()]);
  }

  /**
   * Gets indexed data.
   *
   * @return array
   *   Indexed data.
   */
  public function getIndexedData(): array {
    return $this->data;
  }

}
