<?php

declare(strict_types=1);

namespace Drupal\Tests\data_pipelines\Kernel;

use Drupal\data_pipelines\Entity\Dataset;

/**
 * Defines a class for testing the dataset entity.
 *
 * @group data_pipelines
 *
 * @covers \Drupal\data_pipelines\Entity\Dataset
 */
class DatasetEntityTest extends DatasetKernelTestBase {

  /**
   * Tests get plugins.
   */
  public function testGetPlugins() {
    $dataset = Dataset::create([
      'source' => 'csv_file',
      'name' => $this->randomMachineName(),
    ]);
    $this->assertEquals([
      'test_pipeline_1' => 'Test pipeline 1',
      'invalid_pipeline_1' => 'Invalid pipeline 1',
      'invalid_pipeline_2' => 'Pipeline with record transform for fields and view versa',
    ], Dataset::getPipelines($dataset->getFieldDefinition('pipeline'), $dataset));
  }

  /**
   * Tests set setting status.
   */
  public function testStatus() {
    $dataset = Dataset::create([
      'source' => 'csv_file',
      'name' => $this->randomMachineName(),
    ]);
    $this->assertEquals('Pending validation', $dataset->getStatusLabel());
    $dataset->setPendingValidation();
    $this->assertTrue($dataset->isPendingValidation());
    $dataset->setPendingIndex();
    $this->assertTrue($dataset->isPendingIndex());
    $dataset->setIndexingComplete();
    $this->assertTrue($dataset->isIndexed());
  }

  /**
   * Tests logging.
   */
  public function testLogging() {
    $dataset = Dataset::create([
      'source' => 'csv_file',
      'name' => $this->randomMachineName(),
    ]);
    $this->assertEquals([], $dataset->getLogs());
    $message1 = $this->randomMachineName();
    $message2 = $this->randomMachineName();
    $dataset->addLogMessage($message1);
    $this->assertEquals([$message1], $dataset->getLogs());
    $dataset->addLogMessage($message2, FALSE);
    $dataset = $this->reloadDataset($dataset);
    $this->assertEquals([$message1], $dataset->getLogs());
    $dataset->addLogMessage($message2, FALSE);
    $dataset->save();
    $dataset = $this->reloadDataset($dataset);
    $this->assertEquals([$message1, $message2], $dataset->getLogs());
    $dataset->resetLogs(FALSE);
    $this->assertEquals([], $dataset->getLogs());
    $dataset = $this->reloadDataset($dataset);
    $this->assertEquals([$message1, $message2], $dataset->getLogs());
    $dataset->resetLogs();
    $this->assertEquals([], $dataset->getLogs());
    $dataset = $this->reloadDataset($dataset);
    $dataset->resetLogs();
  }

  /**
   * Tests getting source/pipeline labels.
   */
  public function testSourcePipelineLabels() {
    $dataset = $this->createTestDataset();
    $this->assertEquals('CSV String', $dataset->getSourceLabel());
    $this->assertEquals('Test pipeline 1', $dataset->getPipelineLabel());
    $dataset = $this->createTestDataset([
      'pipeline' => 'does_not_exist',
    ]);
    $this->assertEquals('does_not_exist', $dataset->getPipelineLabel());
  }

}
