<?php

declare(strict_types=1);

namespace Drupal\Tests\data_pipelines\Kernel;

use Drupal\data_pipelines\Entity\Dataset;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\data_pipelines\Traits\DatasetTestTrait;
use Drupal\Tests\user\Traits\UserCreationTrait;

/**
 * Defines a base kernel test for testing dataset functionality.
 *
 * @group data_pipelines
 */
abstract class DatasetKernelTestBase extends KernelTestBase {

  use UserCreationTrait;
  use DatasetTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'options',
    'link',
    'file',
    'entity',
    'elasticsearch_connector',
    'data_pipelines',
    'data_pipelines_test',
    'user',
    'system',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->installEntitySchema('user');
    $this->installEntitySchema('file');
    $this->installEntitySchema('data_pipelines');
    $this->installSchema('file', ['file_usage']);
    $this->setUpCurrentUser();
  }

  /**
   * Creates a test dataset.
   *
   * @param array $values
   *   Field values.
   */
  protected function createTestDataset(array $values = []): DatasetInterface {
    $name = $this->randomMachineName();
    $csv = <<<CSV
should_we,firstname,lastname
Y,joe,bloggs
N,betty,bloggs
CSV;
    $dataset = Dataset::create($values + [
      'source' => 'csv_string',
      'pipeline' => 'test_pipeline_1',
      'name' => $name,
      'csv_string' => $csv,
    ]);
    $dataset->save();
    return $dataset;
  }

}
