<?php

declare(strict_types=1);

namespace Drupal\Tests\data_pipelines\Kernel\DatasetSource;

use Drupal\data_pipelines\DatasetData;
use Drupal\data_pipelines\Entity\Dataset;
use Drupal\data_pipelines\Source\DatasetSourceInterface;
use Drupal\data_pipelines\Source\DatasetSourcePluginManager;
use Drupal\Tests\data_pipelines\Kernel\DatasetKernelTestBase;

/**
 * Defines a test for the CsvFile dataset source.
 *
 * @covers \Drupal\data_pipelines\Plugin\DatasetSource\CsvFile
 * @covers \Drupal\data_pipelines\Plugin\DatasetSource\FileBase
 * @covers \Drupal\data_pipelines\Source\DatasetSourcePluginManager
 */
class CsvFileTest extends DatasetKernelTestBase {

  /**
   * Tests extracting data from CSV files.
   */
  public function testExtractDataFromDataSet() {
    $file = $this->getTestFile(dirname(__DIR__, 2) . '/fixtures/test-pipeline-1.csv');
    $manager = \Drupal::service('plugin.manager.data_pipelines_source');
    assert($manager instanceof DatasetSourcePluginManager);
    $instance = $manager->createInstance('csv_file');
    assert($instance instanceof DatasetSourceInterface);
    $dataset = Dataset::create([
      'source' => 'csv_file',
      'pipeline' => 'test_pipeline_1',
      'name' => $this->randomMachineName(),
      'csv_file' => $file,
    ]);
    $data = iterator_to_array($instance->extractDataFromDataSet($dataset));
    $this->assertEquals([
      new DatasetData([
        'should_we' => 'Y',
        'firstname' => 'joe',
        'lastname' => 'bloggs',
      ]),
      new DatasetData([
        'should_we' => 'N',
        'firstname' => 'betty',
        'lastname' => 'bloggs',
      ]),
    ], $data);
  }

}
